@@ -1,9 +1,8 @@
 package Test::Smoke::Patcher;
 use strict;
 
-# $Id$
 use vars qw( $VERSION @EXPORT );
-$VERSION = '0.012';
+$VERSION = '0.004';
 
 use base 'Exporter';
 use File::Spec;
@@ -13,24 +12,21 @@ use Test::Smoke::Util qw( get_regen_headers );
 
 @EXPORT = qw( &TRY_REGEN_HEADERS );
 
-sub MAX_FLAG_COUNT    () { 16 }
-sub ALL_FLAGS         () { (2**MAX_FLAG_COUNT) - 1 }
-sub TRY_REGEN_HEADERS () { 1 }
+sub TRY_REGEN_HEADERS() { 1 }
 
 my %CONFIG = (
+
     df_ddir     => File::Spec->rel2abs( cwd ),
-    df_fdir     => undef,
     df_pfile    => undef,
-    df_patchbin => 'patch',
+    df_patch    => 'patch',
     df_popts    => '',       # '-p1' is added in call_patch()
     df_flags    => 0,
-    df_regen    => 1,        # regen => set/unset TRY_REGEN_HEADERS in flags
     df_oldpatch => 0,
     df_v        => 0,
 
     valid_type => { single => 1, multi => 1 },
-    single     => [qw( pfile patchbin popts flags regen oldpatch )],
-    multi      => [qw( pfile patchbin popts flags regen oldpatch )],
+    single     => [qw( pfile patch popts flags oldpatch )],
+    multi      => [qw( pfile patch popts flags oldpatch )],
 );
 
 =head1 NAME
@@ -117,18 +113,6 @@ The patch-resource can also be specified in four (4) ways.
 
 =back
 
-=head2 TRY_REGEN_HEADERS
-
-Constant: 1
-
-=head2 MAX_FLAG_COUNT 
-
-Constant: 16
-
-=head2 ALL_FLAGS
-
-Constant: 2**MAX_FLAG_COUNT) - 1
-
 =head1 METHODS
 
 =over 4
@@ -140,13 +124,11 @@ Constant: 2**MAX_FLAG_COUNT) - 1
 C<new()> crates the object. Valid types are B<single> and B<multi>.
 Valid keys for C<%args>:
 
-    * ddir:     the build directory
-    * fdir:     the intermediate forest dir (preferred)
-    * pfile:    path to either the patch (single) or a textfile (multi)
-    * popts:    options to pass to 'patch' (-p1)
-    * patchbin: full path to the patch binary (patch)
-    * regen:    flag to set/unset the TRY_REGEN_HEADERS flag
-    * v:        verbosity 0..2
+    * ddir:  the build directory
+    * pfile: path to either the patch (single) or a textfile (multi)
+    * popts: options to pass to 'patch' (-p1)
+    * patch: full path to the patch binary (patch)
+    * v:     verbosity 0..2
 
 =cut
 
@@ -158,7 +140,7 @@ sub new {
     unless ( $type && exists $CONFIG{valid_type}->{ $type } ) {
         defined $type or $type = 'undef';
         require Carp;
-        Carp::croak( "Invalid Patcher-type: '$type'" );
+        Carp::croak "Invalid Patcher-type: '$type'";
     }
 
     my %args_raw = @_ ? UNIVERSAL::isa( $_[0], 'HASH' ) ? %{ $_[0] } : @_ : ();
@@ -171,17 +153,9 @@ sub new {
     my %fields = map {
         my $value = exists $args{$_} ? $args{ $_ } : $CONFIG{ "df_$_" };
         ( $_ => $value )
-    } ( v => ddir => fdir => @{ $CONFIG{ $type } } );
-    $fields{pdir} = File::Spec->rel2abs(
-        defined $fields{fdir} ? $fields{fdir} : $fields{ddir}
-    );
+    } ( v => ddir => @{ $CONFIG{ $type } } );
+    $fields{ddir} = File::Spec->rel2abs( $fields{ddir} );
     $fields{ptype} = $type;
-    if ($fields{regen}) {
-        $fields{flags} = ($fields{flags} | TRY_REGEN_HEADERS) & ALL_FLAGS;
-    }
-    else {
-        $fields{flags} = ($fields{flags} & ~TRY_REGEN_HEADERS) & ALL_FLAGS;
-    }
 
     bless { %fields }, $class;
 }
@@ -226,20 +200,8 @@ sub patch {
     my $self = shift;
 
     my $method = "patch_$self->{ptype}";
-    my $ret = $self->$method( @_ );
-    $ret &&= $self->perl_regen_headers;
-
-    if ( $self->{fdir} ) { # This is a forest setup, re-sync
-        require Test::Smoke::Syncer;
-        my %options = (
-            hdir => $self->{fdir},
-            ddir => $self->{ddir},
-            v    => $self->{v},
-        );
-        my $resync = Test::Smoke::Syncer->new( hardlink => %options );
-        $resync->sync;
-    }
-    return $ret;
+    $self->$method( @_ );
+    $self->perl_regen_headers;
 }
 
 =item perl_regen_headers( )
@@ -250,36 +212,27 @@ Try to run F<regen_headers.pl> if the flag is set.
 
 sub perl_regen_headers {
     my $self = shift;
-    return 1 unless $self->{flags} & TRY_REGEN_HEADERS;
+    return unless $self->{flags} & TRY_REGEN_HEADERS;
 
-    my $regen_headers = get_regen_headers( $self->{pdir} );
-    my $regen_perly = $self->{perly}
-        ? qq|$^X "| . File::Spec->catfile( $self->{pdir}, 'regen_perly.pl' ).
-          qq|"|
-        : "";
-    my @regens = grep $_ => ( $regen_headers, $regen_perly );
-    for my $regen ( @regens ) {
+    my $regen_headers = get_regen_headers( $self->{ddir} );
+    SKIP: if ( $regen_headers ) {
         my $cwd = cwd;
-        chdir $self->{pdir} or return;
+        chdir $self->{ddir} or last SKIP;
         local *RUN_REGEN;
-        if ( open RUN_REGEN, "$regen |" ) {
-            $self->{v} and print "Started [$regen]\n";
+        if ( open RUN_REGEN, "$regen_headers |" ) {
             while ( <RUN_REGEN> ) {
                 $self->{v} and print;
             }
             close RUN_REGEN or do {
                 require Carp;
-                Carp::carp( "Error while running [$regen]" );
-                return;
+                Carp::carp "Error while running [$regen_headers]";
             };
         } else {
             require Carp;
-            Carp::carp( "Could not fork [$regen]" );
-            return;
+            Carp::carp "Could not fork [$regen_headers]";
         }
         chdir $cwd;
     }
-    return 1;
 }
 
 =item $patcher->patch_single( )
@@ -310,18 +263,18 @@ sub patch_single {
         $self->{pfinfo} ||= 'file content';
     } else {
         my $full_name = File::Spec->file_name_is_absolute( $pfile ) 
-            ? $pfile : File::Spec->rel2abs( $pfile, $self->{pdir} );
+            ? $pfile : File::Spec->rel2abs( $pfile, $self->{ddir} );
 
         $self->{pfinfo} = $full_name;
         open PATCH, "< $full_name" or do {
             require Carp;
-            Carp::croak( "Cannot open '$full_name': $!" );
+            Carp::croak "Cannot open '$full_name': $!";
         };
         $content = do { local $/; <PATCH> };
         close PATCH;
     }
 
-    $self->{v} and print "Get patch from $self->{pfinfo}\n";
+    $self->{v} > 1 and print "Get patch from $self->{pfinfo}\n";
     $self->call_patch( \$content, @_ );
 }
 
@@ -353,36 +306,28 @@ sub patch_multi {
         $self->{pfinfo} ||= 'file content';
     } else {
         my $full_name = File::Spec->file_name_is_absolute( $pfile ) 
-            ? $pfile : File::Spec->rel2abs( $pfile, $self->{pdir} );
+            ? $pfile : File::Spec->rel2abs( $pfile, $self->{ddir} );
         $self->{pfinfo} = $full_name;
         open PATCHES, "< $full_name" or do {
             require Carp;
-            Carp::croak( "Cannot open '$self->{pfile}': $!" );
+            Carp::croak "Cannot open '$self->{pfile}': $!";
         };
         chomp( @patches = <PATCHES> );
         close PATCHES;
     }
 
-    $self->{v} and print "Get patchinfo from $self->{pfinfo}\n";
+    $self->{v} > 1 and print "Get patchinfo from $self->{pfinfo}\n";
 
-    my $ok = 1;
     foreach my $patch ( @patches ) {
         next if $patch =~ /^\s*[#]/;
         next if $patch =~ /^\s*$/;
-        if ( $patch =~ /^\s*!\s*perly$/ ) {
-            $self->{perly} = 1;
-            next;
-        }
-        my( $filename, $switches, $descr ) = split /\s*;\s*/, $patch, 3;
-        $descr = $descr ? $descr . " ($filename)" : $filename;
-        eval { $self->patch_single( $filename, $switches, $descr ) };
+        my( $filename, $switches ) = split /\s*;\s*/, $patch, 2;
+        eval { $self->patch_single( $filename, $switches ) };
         if ( $@ ) {
             require Carp;
-            Carp::carp( "[$filename] $@" );
-            $ok = 0;
+            Carp::carp "[$filename] $@";
         }
     }
-    return $ok;
 }
 
 =item $self->_make_opts( $switches )
@@ -414,7 +359,7 @@ C<< $$ref_to_content >> to it. It will Carp::croak() on any error!
 =cut
 
 sub call_patch {
-    my( $self, $ref_to_content, $switches, $descr ) = @_;
+    my( $self, $ref_to_content, $switches ) = @_;
 
     local *PATCHBIN;
 
@@ -423,36 +368,29 @@ sub call_patch {
     my $redir = $self->{v} ? "" : ">" . File::Spec->devnull . " 2>&1";
 
     my $cwd = cwd();
-    chdir $self->{pdir} or do {
+    chdir $self->{ddir} or do {
         require Carp;
-        Carp::croak( "Cannot chdir($self->{pdir}): $!" );
+        Carp::croak "Cannot chdir($self->{ddir}): $!";
     };
 
     # patch is verbose enough if $self->{v} == 1
     $self->{v} > 1 and 
-        print "[$self->{pfinfo}] | $self->{patchbin} $opts $redir\n";
+        print "[$self->{pfinfo}] | $self->{patch} $opts $redir\n";
 
-    if ( open PATCHBIN, "| $self->{patchbin} $opts $redir" ) {
+    if ( open PATCHBIN, "| $self->{patch} $opts $redir" ) {
         binmode PATCHBIN;
         print PATCHBIN $$ref_to_content;
         close PATCHBIN or do {
             require Carp;
-            Carp::croak( "Error while patching from '$self->{pfinfo}': $!" );
+            Carp::croak "Error while patching from '$self->{pfinfo}': $!";
         };
     } else {
         require Carp;
-        Carp::croak( "Cannot fork ($self->{patchbin}): $!" );
+        Carp::croak "Cannot fork ($self->{patch}): $!";
     }
-
-    # Add a line to patchlevel.h if $descr
-    if ( defined $descr ) {
-        require Test::Smoke::Util;
-        Test::Smoke::Util::set_local_patch( $self->{pdir}, $descr );
-    }
-
     chdir $cwd or do {
         require Carp;
-        Carp::croak( "Cannot chdir($cwd) back: $!" );
+        Carp::croak "Cannot chdir($cwd) back: $!";
     };
 }
 
