@@ -1,20 +1,15 @@
 package TestLib;
 use strict;
 
-# $Id$
 use vars qw( $VERSION @EXPORT );
-$VERSION = '0.06';
-
-use Test::Smoke::Util qw( whereis );
-
 use base 'Exporter';
+$VERSION = '0.01';
+
 @EXPORT = qw( 
-    &whereis
-    &find_a_patch
+    &whereis 
     &find_unzip &do_unzip
     &find_untargz &do_untargz
-    &manify_path
-    &get_dir &get_file &put_file
+    &get_dir &get_file 
     &rmtree &mkpath
 );
 
@@ -34,32 +29,35 @@ What is in here?
 
 =cut
 
-use Config;
 use File::Find;
-use File::Spec::Functions qw( :DEFAULT abs2rel rel2abs
-                              splitdir splitpath catpath);
+use File::Spec;
 require File::Path;
 use Cwd;
 
-=item manify_path( $path )
+=item whereis( $prog )
 
-Do a OS-specific split on the path, and join with '/' for MANIFEST
-format.
+Try to find an executable instance of C<$prog> in $ENV{PATH}.
+
+Rreturns a full file-path (with extension) to it.
 
 =cut
 
-sub manify_path($) {
-    my $path = shift or return;
-    # There should be no volume on these file_paths
-    $path = File::Spec->canonpath( $path );
-    my( undef, $dirs, $file ) = File::Spec->splitpath( $path );
+sub whereis {
+    my $prog = shift;
+    return undef unless $prog; # you shouldn't call it '0'!
 
-    my @subdirs = grep $_ && length $_ => File::Spec->splitdir( $dirs );
-    $^O eq 'VMS' and $file =~ s/\.$//;
+    my $p_sep = $Config::Config{path_sep};
+    my @path = split /\Q$p_sep\E/, $ENV{PATH};
+    my @pext = split /\Q$p_sep\E/, $ENV{PATHEXT} || '';
+    unshift @pext, '';
 
-    push @subdirs, $file;
-
-    return join '/', @subdirs;
+    foreach my $dir ( @path ) {
+        foreach my $ext ( @pext ) {
+            my $fname = File::Spec->catfile( $dir, "$prog$ext" );
+            return $fname if -x $fname;
+        }
+    }
+    return '';
 }
 
 =item get_dir( $path )
@@ -70,16 +68,13 @@ Returns a list of filenames (no directory-names) in C<$path>.
 
 sub get_dir($) {
     my( $path ) = @_;
-    my $cwd = cwd();
-    chdir $path or die "Cannot chdir($path): $!";
     my @files;
     find sub {
         -f or return;
-        my $cname = File::Spec->canonpath( $File::Find::name );
-        push @files, $cname;
-    }, '.';
+        (my $name = $File::Find::name ) =~ s/^\Q$path\E//;
+        push @files, $name;
+    }, $path;
 
-    chdir $cwd or die "Cannot chdir($cwd) back: $!";
     return @files;
 }
 
@@ -106,33 +101,6 @@ sub get_file {
     return wantarray ? @content : join "", @content;
 }
 
-=item put_file( $content, @path )
-
-The contents of C<@path> are passed to B<< File::Spec->catfile() >>
-
-Writes C<$content> to that file and returns the success/failure.
-
-=cut
-
-sub put_file {
-    my $contents = shift;
-    my $filename = File::Spec->catfile( @_ );
-
-    local *MYFILE;
-    if ( open MYFILE, "> $filename" ) {
-        print MYFILE $contents;
-        close MYFILE or do {
-            warn "Cannot close (@{[cwd]})$filename: $!";
-            return;
-        };
-    } else {
-        warn "Cannot create (@{[cwd]})$filename: $!";
-        return;
-    }
-
-    return 1;
-}
-
 =item rmtree( @_ )
 
 This is B<< File::Path::rmtree() >>.
@@ -149,22 +117,6 @@ This is B<< File::Path::mkpath() >>.
 
 sub mkpath { File::Path::mkpath( @_ ) }
 
-=item find_a_patch()
-
-Loop over some known names for gnu-patch and see if they know about --version.
-
-=cut
-
-sub find_a_patch {
-
-    my $patch_bin;
-    foreach my $patch (qw( gpatch npatch patch )) {
-        $patch_bin = whereis( $patch ) or next;
-        my $version = `$patch_bin --version 2>&1`;
-        $? or return $patch_bin;
-    }
-}
-
 =item find_unzip()
 
 Check C<< wheris( 'gzip' ) >> or C<< eval{ require Compress::Zlib } >>.
@@ -189,7 +141,7 @@ sub find_unzip {
 Returns the gunzipped contents of C<$uzfile>.
 
 =cut
-
+        
 sub do_unzip {
     my( $unzip, $uzfile ) = @_;
     return undef unless -f $uzfile;
@@ -199,7 +151,7 @@ sub do_unzip {
         require Compress::Zlib;
         my $unzipper = Compress::Zlib::gzopen( $uzfile, 'rb' ) or do {
             require Carp;
-            Carp::carp( "Can't open '$uzfile': $Compress::Zlib::gzerrno" );
+            Carp::carp "Can't open '$uzfile': $Compress::Zlib::gzerrno";
             return undef;
         };
 
@@ -208,7 +160,7 @@ sub do_unzip {
 
         unless ( $Compress::Zlib::gzerrno == Compress::Zlib::Z_STREAM_END() ) {
             require Carp;
-            Carp::carp( "Error reading '$uzfile': $Compress::Zlib::gzerrno" );
+            Carp::carp "Error reading '$uzfile': $Compress::Zlib::gzerrno" ;
         }
 
         $unzipper->gzclose;
@@ -242,11 +194,7 @@ sub find_untargz {
     unless ( $uncompress ) {
         eval { require Archive::Tar; };
         unless ( $@ ) {
-            if ( $Archive::Tar::VERSION >= 0.99 ) {
-                eval { require IO::Zlib };
-            } else {
-                eval { require Compress::Zlib };
-            }
+            eval { require Compress::Zlib; };
             $uncompress = 'Archive::Tar' unless $@;
         }
     }
@@ -284,8 +232,6 @@ sub do_untargz {
         $archive->extract( @files );
 
     } else { # assume command
-        $^O eq 'VMS' and return vms_untargz( $untgz, $tgzfile );
-
         my $command = sprintf $untgz, $tgzfile;
         $command .= " $tgzfile" if $command eq $untgz;
 
@@ -298,42 +244,6 @@ sub do_untargz {
     return 1;
 }
 
-=item vms_untargz( $untargz, $tgzfile )
-
-Gunzip and extract the archive in C<$tgzfile>.
-
-=cut
-
-sub vms_untargz {
-    my( $cmd, $file ) = @_;
-    my( $vol, $path, $fname ) = splitpath( $file );
-    my @parts = split /[.@#]/, $fname;
-    if ( @parts > 1 ) {
-        my $ext = ( pop @parts ) || '';
-        $fname = join( "_", @parts ) . ".$ext";
-    }
-    $file = catpath( $vol, $path, $fname );
-
-    my( $gzip_cmd, $tar_cmd ) = split /\s*\|\s*/, $cmd;
-    my $gzip = $gzip_cmd =~ /^(\S+)/ ? $1 : 'GZIP';
-    my $tar  = $tar_cmd  =~ /^(\S+)/
-        ? $1 : (whereis( 'vmstar' ) || whereis( 'tar' ) );
-
-    local *TMPCOM;
-    open TMPCOM, "> TS-UNTGZ.COM" or return 0;
-    print TMPCOM <<EO_UNTGZ; close TMPCOM or return 0;
-\$ define/user sys\$output TS-UNTGZ.TAR
-\$ $gzip "-cd" $file
-\$ $tar "-xf" TS-UNTGZ.TAR
-\$ delete TS-UNTGZ.TAR;*
-EO_UNTGZ
-
-    my $ret = system "\@TS-UNTGZ.COM";
-    1 while unlink "TS-UNTGZ.COM";
-
-    return ! $ret;
-}
-
 1;
 
 =back
